**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Namz             modelEco_labour3.gms
Sequence         2 - The farm model
Type             LP
GAMS language    Show model status, loosen all constraints
Description
" A given farm can grow three types of crop, wheat, maize and tomato, and use two crop practices, extensive and intensive.
The area to be cultivated must be determined for each production-technology combination, knowing that :
The objective of the farmer is maximize his income.

Water needs are as follows :
               Water needs (thousands of m3)
Technology        extensive        intensive
Wheat                0                2
Maize                4                6
Tomato               3                5
 Labour needs are as follows :
                  Labour needs (h/ha)
                  Technology            Period
                                 Winter        Summer
Wheat             extensive        10             5
                  intensive        15            10
Maize             extensive        10            35
                  intensive        10            40
Tomato            extensive        10            70
                  intensive        10            90
Yields and costs are as follows :
                        Yield (ton/ha)                    Cost (/ha)
Technology        extensive        intensive        extensive        Intensive
Wheat                4.5             5.0              250              300
Maize                8.0            10.0              400              500
Tomato              13.0            16.0             1200             1350
 The selling price of wheat is 150/ton, that of maize 150/ton, and that of tomato 185/ton.
The farm area is 50 ha, and the farmer can work 1000 hours in summer and 1000 hours in winter, and has 150 thousand m3 for irrigation. "

$Offtext

*----------                          DECLARATION                       ----------*
sets
C crops         /wheat, maize, tomato/
T Technology    /ext, int/
S Season        /winter, summer/
;

*----------                          DATA                       ----------*
scalar
LAND_A    land availability in hectares                 /50/
WATER_A   water availability                           /150/
PSLF      hourly price of hired labour                  /10/
WaterP    water price                                   /50/
LandP     land price                                   /300/
;

parameter
LABOUR_A(S) labour availability in hours
/summer     1000
 winter     1000/
;

table
LN(C,T,S) labour needs per crop and technology (hours)
                winter   summer
 wheat.ext       10         5
 wheat.int       15        10
 maize.ext       10        35
 maize.int       10        40
 tomato.ext      10        70
 tomato.int      10        90
;

table WN(C,T) water needs per crop and technology
              ext   int
 wheat         0     2
 maize         4     6
 tomato        3     5
;

table
Yield (C, T) yield per crop in tonnes per hectare
          ext     int
wheat     4.5     5.0
maize     8.0    10.0
tomato   13.0    16.0
;

parameter
PC (C) selling price per crop in euros
/ wheat    150
  maize    150
  tomato   185/
;

table
COST (C, T) variable cost per crop in euros per ha
          ext    int
wheat     250    300
maize     400    500
tomato   1200   1350
;

parameter
GM(C, T) gross margin per crop in euros    ;
GM(C, T) = yield(C, T)*PC(C)-COST(C, T);

*----------                         MODEL                          ----------*
variables
Z   total farm income  (euros)
;

positive variables
X       area per crop (hectares)
SLF(S)  number of hours of hired labour  (hours)
P_water purchased water
P_land  purchased land
;

equations
OBJECTIVE      objective function
LAND           land equation
LABOUR(S)      labour equation
WATER          water equation
;

OBJECTIVE..  sum ((C,T), GM(C, T)* X(C, T)) - sum(S, SLF(S)*PSLF) -P_water*WaterP -LandP*P_land =E= Z ;

LAND..       sum((C,T), X(C, T)) =l= LAND_A + P_land ;

LABOUR(S)..  sum((C,T), LN(C, T, S)*X(C, T)) =L= LABOUR_A(S) + SLF(S);

WATER..      sum((C,T), WN(C,T)*X(C,T)) =l= WATER_A + P_water ;


model modelS2 first example /all/;

*----------                        SOLUTION                         ----------*
solve modelS2 using LP maximizing Z;


parameter RESULT ;

RESULT(c,t) = X.L(c,t);
RESULT('Land', 'Total') = LAND.L;
RESULT('Land', 'Marginal')=LAND.M;
RESULT('Labour_Winter', 'Total') = LABOUR.L('winter');
RESULT('Labour_Winter', 'Marginal')= LABOUR.M('winter');
RESULT('Labour_Summer', 'Total') = LABOUR.L('summer');
RESULT('Labour_Summer', 'Marginal')=  LABOUR.M('summer');
RESULT('SLF_Winter', 'Total')= SLF.L('winter');
RESULT('SLF_Summer', 'Total')= SLF.L('summer');
RESULT('Water','Total') = WATER.L;
RESULT('Water', 'Marginal')= WATER.M;
RESULT('P_water', 'Total') =P_Water.L ;
RESULT(c,'TOTAL') = sum(t, X.L(c,t));
RESULT('ModelStatus', 'Total')= modelS2.ModelStat ;
Display RESULT ;


execute_unload 'resultat_travail3_B.gdx' RESULT ;
execute 'gdxxrw.exe resultat_travail3_B.gdx par=RESULT'     ;
